@@ -370,6 +370,8 @@ impl From<DBLeg> for Leg {
             walking: value.typ == "FUSSWEG",
             transfer: false, // TODO
             distance: value.distanz,
+            #[cfg(feature = "polylines")]
+            polyline: None,
         }
     }
 }
